#include "common.h"
#include <sndfile.h>


bool checkSoundFile(std::string file) {

    SNDFILE *sf;
    SF_INFO sfinfo;
    char cha_fname[PATH_MAX];
    snprintf(cha_fname, sizeof(cha_fname)-1, "%s", file.c_str());
    sf = sf_open(cha_fname, SFM_READ, &sfinfo);
//	sf = sf_open(file.c_str(), SFM_READ, &sfinfo);
    if (!sf) {
        return false;
    } else {
        sf_close(sf);
        return  true;
    }
}

HarkConfigFileType GetHarkConfigTextFileType(const std::string& filename)
{
    const HarkConfigFileType types[] = {
        HarkConfigFileType::Unknown,
        HarkConfigFileType::ImpulseResponseListFile,
        HarkConfigFileType::TSPListFile,
        HarkConfigFileType::MicArrayLocationFile,
        HarkConfigFileType::NoiseLocationFile
    };

    try
    {
        int type = harkio::TextData().checkFileIdentifier(filename);
        if (0 <= type && type < static_cast<int>(sizeof(types) / sizeof(types[0])))
        {
            return types[type];
        }
        else
        {
            return HarkConfigFileType::Unknown;
        }
    }
    catch (const harkio::Error& e)
    {
        return HarkConfigFileType::Unknown;
    }
    catch (...)
    {
        return HarkConfigFileType::Unknown;
    }
}

HarkConfigFileType GetHarkConfigXMLFileType(const std::string& filename)
{
    static const std::map<std::string, HarkConfigFileType> types = {
        {"ImpulseResponseListFile", HarkConfigFileType::ImpulseResponseListFile},
        {"TSPListFile", HarkConfigFileType::TSPListFile},
        {"MicArrayLocationFile", HarkConfigFileType::MicArrayLocationFile},
        {"NoiseLocationFile", HarkConfigFileType::NoiseLocationFile}
    };

    try
    {
        auto hc_file = harkio2::harkconfig::HarkConfigFileXMLReader(filename).Read();
        auto find_result = types.find(hc_file->GetId());
        if (find_result != types.end())
        {
            return find_result->second;
        }
        else
        {
            return HarkConfigFileType::Unknown;
        }
    }
    catch (const harkio2::AnalyzeError& e)
    {
        return HarkConfigFileType::Unknown;
    }
    catch (...)
    {
        return HarkConfigFileType::Unknown;
    }
}

std::pair<HarkConfigFileFormatType, HarkConfigFileType> GetHarkConfigFileType(const std::string& filename)
{
    auto type = GetHarkConfigXMLFileType(filename);
    if (type != HarkConfigFileType::Unknown)
    {
        return std::make_pair(HarkConfigFileFormatType::XML, type);
    }

    type = GetHarkConfigTextFileType(filename);
    if (type != HarkConfigFileType::Unknown)
    {
        return std::make_pair(HarkConfigFileFormatType::Text, type);
    }

    return std::make_pair(HarkConfigFileFormatType::Unknown, HarkConfigFileType::Unknown);
}



QString getUserName()
{
    QString name;
    QStringList environment = QProcess::systemEnvironment();
    for (int i=0; i < environment.size(); i++)  {
        QRegExp reg("(?:USER|USERNAME)=(.+)");
        int ret = reg.indexIn(environment[i]);
        if (ret >= 0) {
            name = reg.cap(1);
            break;
        }
    }
    return name;
}
